@@ -13,7 +13,13 @@ from playwright.async_api import (
 
 from nonebot_plugin_htmlrender.config import plugin_config
 from nonebot_plugin_htmlrender.install import install_browser
-from nonebot_plugin_htmlrender.utils import proxy_settings, suppress_and_log, with_lock
+from nonebot_plugin_htmlrender.utils import (
+    _prepare_playwright_env_vars,
+    clean_playwright_cache,
+    proxy_settings,
+    suppress_and_log,
+    with_lock,
+)
 
 _browser: Optional[Browser] = None
 _playwright: Optional[Playwright] = None
@@ -40,22 +46,6 @@ async def _launch(browser_type: str, **kwargs) -> Browser:
     return await _browser_cls.launch(**kwargs)
 
 
-async def init_browser(**kwargs) -> Browser:
-    """
-    初始化浏览器实例。
-
-    Args:
-        **kwargs: 传递给`playwright.launch`的关键字参数。
-
-    Returns:
-        Browser: 浏览器实例。
-
-    Raises:
-        RuntimeError: 如果浏览器无法启动或安装失败。
-    """
-    return await start_browser(**kwargs)
-
-
 @asynccontextmanager
 async def get_new_page(device_scale_factor: float = 2, **kwargs) -> AsyncIterator[Page]:
     """
@@ -88,7 +78,7 @@ async def get_browser(**kwargs) -> Browser:
     if _browser and _browser.is_connected():
         return _browser
 
-    return await init_browser(**kwargs)
+    return await startup_htmlrender(**kwargs)
 
 
 async def _connect_via_cdp(**kwargs) -> Browser:
@@ -106,12 +96,12 @@ async def _connect_via_cdp(**kwargs) -> Browser:
     """
     kwargs["endpoint_url"] = plugin_config.htmlrender_connect_over_cdp
     logger.info(
-        f"正在使用 CDP 连接 Chromium({plugin_config.htmlrender_connect_over_cdp})"
+        f"Connecting to Chromium via CDP ({plugin_config.htmlrender_connect_over_cdp})"
     )
     if _playwright is not None:
         return await _playwright.chromium.connect_over_cdp(**kwargs)
     else:
-        raise RuntimeError("Playwright 未初始化")
+        raise RuntimeError("Playwright is not initialized")
 
 
 async def _connect(browser_type: str, **kwargs) -> Browser:
@@ -131,7 +121,8 @@ async def _connect(browser_type: str, **kwargs) -> Browser:
     _browser_cls: BrowserType = getattr(_playwright, browser_type)
     kwargs["ws_endpoint"] = plugin_config.htmlrender_connect
     logger.info(
-        f"正在使用 Playwright 协议连接 {browser_type}({plugin_config.htmlrender_connect})"
+        f"Connecting to {browser_type.capitalize()} via "
+        f"WebSocket endpoint: {plugin_config.htmlrender_connect}"
     )
     if _playwright is not None:
         return await _browser_cls.connect(**kwargs)
@@ -140,7 +131,7 @@ async def _connect(browser_type: str, **kwargs) -> Browser:
 
 
 @with_lock
-async def start_browser(**kwargs) -> Browser:
+async def startup_htmlrender(**kwargs) -> Browser:
     """
     启动 Playwright 浏览器实例。
 
@@ -152,8 +143,12 @@ async def start_browser(**kwargs) -> Browser:
     """
     global _browser, _playwright
 
-    await shutdown_browser()
+    await shutdown_htmlrender()
+    clean_playwright_cache()
+    _prepare_playwright_env_vars()
+
     _playwright = await async_playwright().start()
+    logger.debug("Playwright started")
 
     if (
         plugin_config.htmlrender_browser == "chromium"
@@ -174,35 +169,62 @@ async def start_browser(**kwargs) -> Browser:
 
         if plugin_config.htmlrender_browser_executable_path:
             kwargs["executable_path"] = plugin_config.htmlrender_browser_executable_path
+            try:
+                _browser = await _launch(plugin_config.htmlrender_browser, **kwargs)
+            except Exception as e:
+                raise RuntimeError(
+                    f"Failed to launch browser with executable path"
+                    f" '{plugin_config.htmlrender_browser_executable_path}': {e}"
+                ) from e
         else:
             try:
-                await check_playwright_env(**kwargs)
+                _browser = await check_playwright_env(**kwargs)
             except RuntimeError:
                 await install_browser()
-                await check_playwright_env(**kwargs)
-
-        _browser = await _launch(plugin_config.htmlrender_browser, **kwargs)
+                _browser = await check_playwright_env(**kwargs)
 
     return _browser
 
 
-async def shutdown_browser() -> None:
+async def shutdown_htmlrender() -> None:
     """关闭浏览器和 Playwright 实例。"""
     if _browser:
-        with suppress_and_log():
-            await _browser.close()
+        if not _browser.is_connected():
+            logger.info("Browser was already disconnected, skipping close.")
+        else:
+            with suppress_and_log():
+                logger.debug("Disconnecting browser...")
+                await _browser.close()
+                logger.info("Disconnected browser.")
     if _playwright:
         with suppress_and_log():
+            logger.debug("Stopping Playwright...")
             await _playwright.stop()
+            logger.info("Playwright stopped.")
 
 
-async def check_playwright_env(**kwargs):
-    """Check Playwright environment."""
+async def check_playwright_env(**kwargs) -> Browser:
+    """
+    检查Playwright环境，复用_launch方法避免逻辑重复。
+
+    Args:
+        **kwargs: 传递给`playwright.launch`的关键字参数。
+
+    Raises:
+        RuntimeError: 如果Playwright环境设置不正确。
+    """
     logger.info("Checking Playwright environment...")
+    global _browser, _playwright
+
     try:
-        async with async_playwright() as p:
-            await getattr(p, plugin_config.htmlrender_browser).launch(**kwargs)
+        _playwright = await async_playwright().start()
+        _browser = await _launch(plugin_config.htmlrender_browser, **kwargs)
+        logger.success("Playwright environment is set up correctly.")
+        return _browser
+
     except Exception as e:
+        await shutdown_htmlrender()
+
         raise RuntimeError(
             "Playwright environment is not set up correctly. "
             "Refer to https://playwright.dev/python/docs/intro#system-requirements"
